==> nomad_media_cli-0.0.3.tar.gz: nomad_media_cli-0.0.3/nomad_media_cli/commands/common/asset/create_screenshot_at_timecode.py <==
import click
import json
import sys
from nomad_media_cli.helpers.get_id_from_url import get_id_from_url
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--id", help="The ID of the asset.")
@click.option("--url", help="The Nomad URL of the Asset (file or folder) to create the screenshot for (bucket::object-key).")
@click.option("--object-key", help="Object-key of the Asset (file or folder) to create the screenshot for. This option assumes the default bucket that was previously set with the `set-bucket` command.")
@click.option("--time-code", help="The time code of the screenshot. Format: hh:mm:ss;ff.")
@click.pass_context
def create_screenshot_at_timecode(ctx, id, url, object_key, time_code):
    """Create screenshot at timecode"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    if not id and not url and not object_key:
        click.echo(json.dumps({"error": "Please provide an id, url, or object-key."}))
        sys.exit(1)

    if url or object_key:       
        id = get_id_from_url(ctx, url, object_key, nomad_sdk)  
        
    try:
        result = nomad_sdk.create_screenshot_at_timecode(id, time_code)
        
        if not result:
            click.echo(json.dumps({"error": f"Asset with id {id} not found."}))
            sys.exit(1)

        click.echo(json.dumps(result, indent=4))

    except Exception as e:
        click.echo(json.dumps({"error": f"Error creating screenshot at timecode: {e}"}))
        sys.exit(1)

==> nomad_media_cli-0.1.2a1.tar.gz: nomad_media_cli-0.1.2a1/nomad_media_cli/commands/common/asset/create_screenshot_at_timecode.py <==
import click
import json
import sys
from nomad_media_cli.helpers.get_id_from_url import get_id_from_url
from nomad_media_cli.helpers.utils import initialize_sdk

@click.command()
@click.option("--id", help="The ID of the Asset (must be a video) to create a screenshot for.")
@click.option("--url", help="The Nomad URL of the Asset (must be a video) to create the screenshot for (bucket::object-key).")
@click.option("--object-key", help="Object-key of the Asset (must be a video) to create the screenshot for. This option assumes the default bucket that was previously set with the `set-bucket` command.")
@click.option("--time-code", help="The time code of the screenshot. Format: hh:mm:ss;ff.")
@click.pass_context
def create_screenshot_at_timecode(ctx, id, url, object_key, time_code):
    """Create screenshot at timecode"""
    initialize_sdk(ctx)
    nomad_sdk = ctx.obj["nomad_sdk"]

    if not id and not url and not object_key:
        click.echo(json.dumps({"error": "Please provide an id, url, or object-key."}))
        sys.exit(1)

    if url or object_key:       
        id = get_id_from_url(ctx, url, object_key, nomad_sdk)  
        
    try:
        result = nomad_sdk.create_screenshot_at_timecode(id, time_code)
        
        if not result:
            click.echo(json.dumps({"error": f"Asset with id {id} not found."}))
            sys.exit(1)

        click.echo(json.dumps(result, indent=4))

    except Exception as e:
        click.echo(json.dumps({"error": f"Error creating screenshot at timecode: {e}"}))
        sys.exit(1)
